@@ -1,4 +1,4 @@
-from kbrainsdk.validation.ai import validate_ai_decide, validate_ai_categorize
+from kbrainsdk.validation.ai import validate_ai_decide, validate_ai_categorize, validate_ai_tag_document
 from kbrainsdk.apibase import APIBase
 
 class AI(APIBase):
@@ -29,4 +29,17 @@ class AI(APIBase):
 
         path = f"/ai/categorize/v1"
         response = self.apiobject.call_endpoint(path, payload, "post")
+        return response
+    
+    def tag_document(self, content, **kwargs):
+        
+        payload = {
+            "content": content,
+            **kwargs
+        }
+
+        validate_ai_tag_document(payload)
+
+        path = f"/ai/tag_document/v1"
+        response = self.apiobject.call_endpoint(path, payload, "post")
         return response
\ No newline at end of file
