@@ -7,7 +7,8 @@ from kbrainsdk.datasets import Datasets
 from kbrainsdk.ingest import Ingest
 from kbrainsdk.ai import AI
 from kbrainsdk.users import User
-from kbrainsdk.messages import Messages
+from kbrainsdk.events import Events
+from kbrainsdk.signalr import SignalR
 
 VALID_MODEL_NAMES = ["gpt-3.5-turbo", "gpt-4", "gpt-3.5-instruct"]
 
@@ -26,7 +27,8 @@ class KBRaiNAPI:
         self.ingest = Ingest(self)
         self.ai = AI(self)
         self.users = User(self)
-        self.messages = Messages(self)
+        self.events = Events(self)
+        self.signalr = SignalR(self)
         
     def healthy(self):
         path = f"/health/v1"
