@@ -1,5 +1,5 @@
 from typing import Any
-from kbrainsdk.validation.llms import validate_aistudio_llms
+from kbrainsdk.validation.llms import validate_aistudio_llms, validate_stream_llm_output
 from kbrainsdk.apibase import APIBase
 
 class LLMs(APIBase):
@@ -86,3 +86,17 @@ class LLMs(APIBase):
             deployment_id='chat'
         )
         return result 
+
+    def stream_llm_output(self, system_prompt:str, messages:list, streaming_args:dict, **kwargs):
+
+        payload = {
+            "system_prompt": system_prompt,
+            "messages": messages,
+            "streaming_args": streaming_args,        
+        }
+
+        validate_stream_llm_output(payload)
+
+        path = f"/llms/stream/v1"
+        response = self.apiobject.call_endpoint(path, payload, "post")
+        return response
\ No newline at end of file
