@@ -24,6 +24,11 @@ def validate_scopes(user_scopes, acceptable_scopes):
     if not has_scope:
         raise APIKeyException("User does not have appropriate access scopes for this endpoint")
 
+def validate_required_parameters(body, required_arguments):
+    missing_values = [value for value in required_arguments if value not in body]
+    if missing_values:
+        raise ValueError("Missing or empty parameter in request body. Requires: {}".format(", ".join(missing_values)))
+
 def get_payload(req):
     if type(req) == dict:
         return req
